@@ -108,6 +108,12 @@ struct rtm
 
 static int if_plumb(int, const struct dhcpcd_ctx *, int, const char *);
 
+int
+os_init(void)
+{
+	return 0;
+}
+
 int
 if_init(struct interface *ifp)
 {
@@ -197,7 +203,7 @@ if_setmac(struct interface *ifp, void *mac, uint8_t maclen)
 }
 
 int
-if_carrier(struct interface *ifp)
+if_carrier(struct interface *ifp, __unused const void *ifadata)
 {
 	kstat_ctl_t		*kcp;
 	kstat_t			*ksp;
@@ -1052,7 +1058,7 @@ if_ifinfo(struct dhcpcd_ctx *ctx, const struct if_msghdr *ifm)
 		state = LINK_UP;
 		flags |= IFF_UP;
 	}
-	dhcpcd_handlecarrier(ctx, state, flags, ifp->name);
+	dhcpcd_handlecarrier(ifp, state, flags);
 	return 0;
 }
 
