@@ -236,9 +236,15 @@ static struct sock_filter ps_seccomp_filter[] = {
 #ifdef __NR_fcntl
 	SECCOMP_ALLOW(__NR_fcntl),
 #endif
+#ifdef __NR_fcntl64
+	SECCOMP_ALLOW(__NR_fcntl64),
+#endif
 #ifdef __NR_fstat
 	SECCOMP_ALLOW(__NR_fstat),
 #endif
+#ifdef __NR_fstat64
+	SECCOMP_ALLOW(__NR_fstat64),
+#endif
 #ifdef __NR_gettimeofday
 	SECCOMP_ALLOW(__NR_gettimeofday),
 #endif
@@ -251,6 +257,8 @@ static struct sock_filter ps_seccomp_filter[] = {
 	SECCOMP_ALLOW_ARG(__NR_ioctl, 1, SIOCGIFINDEX),
 	SECCOMP_ALLOW_ARG(__NR_ioctl, 1, SIOCGIFMTU),
 	SECCOMP_ALLOW_ARG(__NR_ioctl, 1, SIOCGIFVLAN),
+	/* printf over serial terminal requires this */
+	SECCOMP_ALLOW_ARG(__NR_ioctl, 1, TCGETS),
 	/* SECCOMP BPF is newer than nl80211 so we don't need SIOCGIWESSID
 	 * which lives in the impossible to include linux/wireless.h header */
 #endif
